@@ -9,7 +9,7 @@ massspring
 
 using this library you can create great
 simulations of most of physical environments
-which can be calculated presizely.
+which can be calculated precisely.
 you can create many types of objects from which
 "mass" and "spring" are main ones.
 """
@@ -20,7 +20,7 @@ from math import sqrt, pi
 import os
 os.environ["PYGAME_HIDE_SUPPORT_PROMPT"] = '1'
 
-# vairables
+# variables
 # physical constants
 """
 dt is delta time -> time difference between two sections; measured in seconds.
@@ -58,6 +58,8 @@ sp = "spring"
 el = "electricity"
 gv = "gravity"
 cl = "collision"
+INT_MIN = -2 ** 31  # -2147483648
+INT_MAX = 2 ** 31 - 1  # +2147483647
 
 
 # graphical variables
@@ -166,11 +168,15 @@ class NegativeMass(Exception):
 class NonElectricalConductive(Exception):
     pass
 
+# Warnings
 
-class FasterThanSpeedLimitException(Exception):
+
+class FasterThanSpeedLimitException(Warning):
     pass
 
-# Warnings
+
+class FurtherThanPositionLimitException(Warning):
+    pass
 
 
 class SamePosition(Warning):
@@ -196,6 +202,25 @@ class position:
     z = WIND // 2
 
 
+class limit:
+    """ limits for variables and properties of objects """
+    class MIN:
+        x = INT_MIN
+        y = INT_MIN
+        z = INT_MIN
+        vx = -c
+        vy = -c
+        vz = -c
+
+    class MAX:
+        x = INT_MAX
+        y = INT_MAX
+        z = INT_MAX
+        vx = c
+        vy = c
+        vz = c
+        v = c
+
 # objects(physical meaning) classes
 # mass
 
@@ -204,7 +229,7 @@ class mass(object):
     """
     the main mass object class.
     ALL attributes are available in the __init__ method.
-    ALL methods are availeble in the class.
+    ALL methods are available in the class.
     no attribute or method will be added
     to objects unless the user adds it to objects.
     """
@@ -212,8 +237,8 @@ class mass(object):
     def __init__(self,
                  x=0, y=0, z=0, vx=0, vy=0, vz=0,
                  m=1, r=1, q=0,
-                 moveable=True, solid=True, bound=True, gravitateable=False,
-                 resistable=False, electrical=False, conductive=False,
+                 moveable=True, solid=True, bound=True, gravitational=False,
+                 resistible=False, electrical=False, conductive=False,
                  color=(255, 255, 255), visible=True):
         """
         parameters:
@@ -228,8 +253,8 @@ class mass(object):
         moveable means if the object can move or not.
         solid means if the object can hit other objects or not.
         bound means if the object stays in the screen or not.
-        gravitateable means if the object is affected by gravity force or not.
-        resistable means if the object is
+        gravitational means if the object is affected by gravity force or not.
+        resistible means if the object is
                 affected by air resistance force or not.
         electrical means if the object is affected by other objects' electrical
                 force and can affect them by electrical force or not.
@@ -262,8 +287,8 @@ class mass(object):
         self.moveable = moveable
         self.solid = solid
         self.bound = bound
-        self.gravitateable = gravitateable
-        self.resistable = resistable
+        self.gravitational = gravitational
+        self.resistible = resistible
         self.electrical = electrical
         self.conductive = conductive
         self.color = color
@@ -337,7 +362,7 @@ class mass(object):
 
     def set_air_resistance_force(self):
         """ sets the air resistance force to the object """
-        if self.resistable:
+        if self.resistible:
             f = self.air_resistance_force()
             v = self.v()
             if v == 0:
@@ -351,21 +376,41 @@ class mass(object):
 
     def reflect(self):
         """ reflects the object if it hits the walls """
+        # checking if the mass WILL go out of the screen to avoid it.
         if self.bound:
-            if not (-WINW // 2 + self.r < self.x < WINW // 2 - self.r):
+            if not (-WINW // 2 + self.r < self.x + self.vx * dt < WINW // 2 - self.r):
                 self.vx *= -1
-            if not (-WINH // 2 + self.r < self.y < WINH // 2 - self.r):
+            if not (-WINH // 2 + self.r < self.y + self.vy * dt < WINH // 2 - self.r):
                 self.vy *= -1
-            if not (-WIND // 2 + self.r < self.z < WIND // 2 - self.r):
+            if not (-WIND // 2 + self.r < self.z + self.vz * dt < WIND // 2 - self.r):
                 self.vz *= -1
 
     def check_speed_exceeds_limit(self):
+        """
+        raises a warning if the mass has reached the speed of light
+        in vacuum which is highest speed an object can have.
+        """
         tmpv = self.v()
-        if tmpv >= c:
+        if tmpv >= limit.MAX.v:  # tmpv is higher than 0
             # the mass has reached the speed of light in vacuum (or MORE)
             raise FasterThanSpeedLimitException(
                 f"can't go faster than {c}, the speed is {tmpv}")
 
+    def check_position_exceeds_limit(self):
+        """
+        raises a warning if the position is
+        higher than INT_MAX or lower than INT_MIN
+        """
+        if not (limit.MIN.x < self.x < limit.MAX.x):
+            raise FurtherThanPositionLimitException(
+                f"can't place mass.x out of ({limit.MIN.x},{limit.MAX.x}), x is {self.x}")
+        if not (limit.MIN.y < self.y < limit.MAX.y):
+            raise FurtherThanPositionLimitException(
+                f"can't place mass.y out of ({limit.MIN.y},{limit.MAX.y}), y is {self.y}")
+        if not (limit.MIN.z < self.z < limit.MAX.z):
+            raise FurtherThanPositionLimitException(
+                f"can't place mass.z out of ({limit.MIN.z},{limit.MAX.z}), z is {self.z}")
+
     def move(self):
         """
         moves the object according to
@@ -385,6 +430,7 @@ class mass(object):
             self.x += self.vx * dt
             self.y += self.vy * dt
             self.z += self.vz * dt
+            self.check_position_exceeds_limit()
 
     def show_pos_xy(self):
         """ returns the position of the mass on the screen (just x and y) """
@@ -436,7 +482,7 @@ class force(object):
     this class is a raw class used to create other classes of forces.
     the subclasses are 'spring', 'gravity', 'electricity', 'collision'
     since all forces in OUR universe are between two objects, the force
-    class has two 'm1' and 'm2' that the force occures between them.
+    class has two 'm1' and 'm2' that the force occurs between them.
     there are two other attributes too:
     1. name: is just a string of the force name which will be used when
     raising exceptions
@@ -537,7 +583,7 @@ class spring(force):
         m1 and m2 are masses.
         k is the constant of the spring in the Hooke's law.
         nl is the natural length of the spring
-        used to calulate delta x in the Hooke's law.
+        used to calculate delta x in the Hooke's law.
         color and visible: guess!
         """
         self.k = k
@@ -620,7 +666,7 @@ class gravity(force):
         return (G * self.m1.m * self.m2.m) / (h ** 2)
 
     def set_force(self):
-        """ sets the gravity force to the object and its gravital pair """
+        """ sets the gravity force to the object and its gravitational pair """
         f = self.get_force()
         d, dx, dy, dz = self.d()
         if d == 0:
@@ -685,7 +731,7 @@ class electricity(force):
 
     def equalise_charge(self):
         """
-        checks if two objects are conduntive and then
+        checks if two objects are conductive and then
         equalises the electrical charge between them.
         """
         if self.m1.conductive and self.m2.conductive:
@@ -698,7 +744,7 @@ class electricity(force):
 
 class collision(force):
     """
-    the main collision class (beta version).
+    the main collision class
     uses the momentum and kinetic conservation and
     I don't know why it works but according to wikipedia
     the formula and equation are driven from these two equations.
@@ -715,7 +761,7 @@ class collision(force):
         return False
 
     def collide(self):
-        """ collides two objects (beta version) """
+        """ collides two objects """
         # checking if the objects has collided
         if not self.check_collision():
             return
@@ -723,67 +769,48 @@ class collision(force):
         d, dx, dy, dz = self.d()
         if d == 0:
             return 0
-        m1 = self.m1
-        m2 = self.m2
-        u1x = m1.vx
-        u1y = m1.vy
-        u1z = m1.vz
-        u2x = m2.vx
-        u2y = m2.vy
-        u2z = m2.vz
-        # calculating velocities of the first object in 3 directions
-        v1x = (((m1.m - m2.m) * u1x) + (2 * m2.m * u2x)) / (m1.m + m2.m)
-        v1y = (((m1.m - m2.m) * u1y) + (2 * m2.m * u2y)) / (m1.m + m2.m)
-        v1z = (((m1.m - m2.m) * u1z) + (2 * m2.m * u2z)) / (m1.m + m2.m)
-        # calculating velocities of the second object in 3 directions
-        v2x = (((m2.m - m1.m) * u2x) + (2 * m1.m * u1x)) / (m1.m + m2.m)
-        v2y = (((m2.m - m1.m) * u2y) + (2 * m1.m * u1y)) / (m1.m + m2.m)
-        v2z = (((m2.m - m1.m) * u2z) + (2 * m1.m * u1z)) / (m1.m + m2.m)
-        # calculating delta x, y and z for the first object
+        m1 = self.m1.m
+        m2 = self.m2.m
+        u1x = self.m1.vx
+        u1y = self.m1.vy
+        u1z = self.m1.vz
+        u2x = self.m2.vx
+        u2y = self.m2.vy
+        u2z = self.m2.vz
+        u1 = self.m1.v()
+        u2 = self.m2.v()
+        # starting collision
+        # calculating new velocities
+        v1 = (u1 * (m1 - m2) + u2 * 2 * m2) / (m1 + m2)
+        v2 = (u2 * (m2 - m1) + u1 * 2 * m1) / (m1 + m2)
+        # dividing v to vx, vy, vz
+        v1x = v1 * dx / d
+        v1y = v1 * dy / d
+        v1z = v1 * dz / d
+        v2x = v2 * -dx / d
+        v2y = v2 * -dy / d
+        v2z = v2 * -dz / d
+        # calculating delta v
         dv1x = v1x - u1x
         dv1y = v1y - u1y
         dv1z = v1z - u1z
-        # calculating delta x, y and z for the second object
         dv2x = v2x - u2x
         dv2y = v2y - u2y
         dv2z = v2z - u2z
-        # calculating acceleration in 3 directions for the first object
+        # calculating acceleration
         a1x = dv1x / dt
         a1y = dv1y / dt
         a1z = dv1z / dt
-        # calculating acceleration in 3 directions for the second object
         a2x = dv2x / dt
         a2y = dv2y / dt
         a2z = dv2z / dt
-        # calculating force in 3 directions for the first object
-        f1x = a1x * m1.m
-        f1y = a1y * m1.m
-        f1z = a1z * m1.m
-        # calculating force in 3 directions for the second object
-        f2x = a2x * m2.m
-        f2y = a2y * m2.m
-        f2z = a2z * m2.m
-        # using 3d pythagorean equation to
-        # calculate the absolute value of the forces
-        f1 = hypot3d(f1x, f1y, f1z)
-        f2 = hypot3d(f2x, f2y, f2z)
-        # now using the similarity of the pyramid of forces and
-        # the pyramid of distances between the centers of spheres
-        f1nx = f1 * dx / d
-        f1ny = f1 * dy / d
-        f1nz = f1 * dz / d
-        # doing the same for the second object
-        f2nx = f2 * dx / d
-        f2ny = f2 * dy / d
-        f2nz = f2 * dz / d
-        # adding new forces to the old ones for the first object
-        m1.fx += f1nx
-        m1.fy += f1ny
-        m1.fz += f1nz
-        # adding new forces to the old ones for the second object
-        m2.fx -= f2nx
-        m2.fy -= f2ny
-        m2.fz -= f2nz
+        # calculating and adding forces
+        self.m1.fx += a1x * m1
+        self.m1.fy += a1y * m1
+        self.m1.fz += a1z * m1
+        self.m2.fx += a2x * m2
+        self.m2.fy += a2y * m2
+        self.m2.fz += a2z * m2
         # the collision is done!
         # equalising the electrical charges of two objects
         # (if they are conductive)
@@ -802,7 +829,7 @@ def create_all_collisions():
 def create_all_gravities():
     for i, m1 in enumerate(mass_lis):
         for _, m2 in enumerate(mass_lis[i+1:]):
-            if m1.gravitateable and m2.gravitateable:
+            if m1.gravitational and m2.gravitational:
                 gravity(m1, m2)
 
 
